@@ -9,13 +9,19 @@ def formatcc(text_to_search):
             cc_end = ccmatches.span()[1]
             #print(ccmatches.span(0))
             text_to_search = text_to_search[cc_end-1:]
-            if cc[0] == 3:
-                pattern = re.compile(r'\d{4}\D')
+            if cc[0] == '3':
+                pattern = re.compile(r'\D\d{4}(\D|$)')
             else:
-                pattern = re.compile(r'\d{3}\D')
+                pattern = re.compile(r'\D\d{3}(\D|$)')
             cvv = pattern.search(text_to_search)
             if cvv is not None:
                 cvv = cvv[0]
+                if cc[0] == '3':
+                    cvv = re.search(r'\d{4}',cvv)
+                    cvv = cvv[0]
+                else:
+                    cvv = re.search(r'\d{4}',cvv)
+                    cvv = cvv[0]
                 yy = re.search(r'\D(2|202)[1-9]',text_to_search)
                 if yy is not None:
                     yy = yy[0]
@@ -31,7 +37,7 @@ def formatcc(text_to_search):
                     return "Invalid Expiry Year."
                 
             else:
-                return "Ivalid CVV."
+                return "Invalid CVV."
             return f"{cc}|{mm}|{yy}|{cvv}"
 
     else:
